@@ -287,7 +287,7 @@ void Akonadi::AkonadiContactEditor::saveContactInAddressBook()
             QPointer<CollectionDialog> dlg = new CollectionDialog(this);
             dlg->setMimeTypeFilter(mimeTypeFilter);
             dlg->setAccessRightsFilter(Collection::CanCreateItem);
-            dlg->setWindowTitle(i18n("Select Address Book"));
+            dlg->setWindowTitle(i18nc("@title:window", "Select Address Book"));
             dlg->setDescription(i18n("Select the address book the new contact shall be saved in:"));
             if (dlg->exec() == QDialog::Accepted) {
                 setDefaultAddressBook(dlg->selectedCollection());
